doAnneal <- function(X, Y, outputPath, tInit=50, tAlpha=0.03, tFactor=1, nIter=10, epsGuess=0.03, epsStop=0.1, 
                     maxIter=100, plotFlag=FALSE, saveFlag=FALSE, loggingFlag=FALSE){
  p <- ncol(X)
  P <- hasse(constructPoset(hyperCube(p), map2HyperCube(X,Y), eps=epsGuess)$poset[[1]])
  params <- guessParams(X, Y, P)
  params <- doEm(X, Y, params, eps=epsStop, maxIter=maxIter)
	T <- tInit
	logLikNext <- matrix(0, nc=p, nr=p) # Re-initialize possible logliks
	weightsNext <- NULL
	parsNext <- list()
	annealingList <- list()
	for (i in 1:nIter){
    cat("###############################################################################\n")
		cat("Annealing loop:", i, "lObs:", params$lObs, "T:", T, "\n")	
    cat("###############################################################################\n")
		tryCatch( edgeResult <- tryEdge(X, Y, params, T, tAlpha=tAlpha, logLikNext, 
                                    weightsNext, parsNext, eps=epsStop, maxIter=maxIter, 
                                    logging=loggingFlag), 
      error=function(e){
      cat("###############################################################################\n")
			cat("Error occured, resetting parameters!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n")
			cat("###############################################################################\n")
  			edgeResult <- guessParams(X, Y, P) 
  			logLikNext <- matrix(0, nc=p, nr=p) # Re-initialize possible logliks
  			weightsNext <- NULL
  			parsNext <- list()
			}
		)
		logLikNext <- edgeResult$logLikNext
		weightsNext <- edgeResult$weightsNext
		parsNext <- edgeResult$parsNext
		annealingList[[i]] <- params <- edgeResult$params
		if (plotFlag){
		  pdf(file=paste(outputPath, "Plots_", i, "_", round(T,2), ".pdf", sep=""), width=12, height=9)
        par(mfrow=c(1,2), cex.sub=0.7, cex.main=0.8, cex.lab=0.7, cex.axis=0.7)
        plotPoset(params$P, vertexLabels=paste(colnames(X), round(params$thetas, 2), sep="\n"), 
          main=paste("T: ", round(T,1), ", lObs: ", round(params$lObs, 2), sep=""),
          sub=paste("Epsilon: ", round(params$epsilon,3), ", Sigma2: ", round(params$sigma2,3), 
										"\nVertex labels: Fitted thetas",
										"\nFitted mus: ", paste(round(params$mus,3), collapse=", "),
										sep=""), vertex.size=40, edge.arrow.size=0.2, vertex.label.cex=0.6)
				ug <- round(colSums(params$respMat),0)
				plotIsotonic(params$mus, params$G, params$H, colnames(X), ug, layout="reingold",
											sub="Fitted genotype lattice\nVertex labels: Genotype, expeceted count, fitted mu at genotype.", 
											vertex.size=40, edge.arrow.size=0.2, vertex.label.cex=0.6)		
		  dev.off()
		}
		if (saveFlag){
		  save(edgeResult, file=paste(outputPath, "Results_", i, "_", round(T,2), ".Rdata", sep=""))
		}
		(T <- T*((p-tFactor)/p))
	}
	keepParams <- annealingList[[1]]
  for (i in 1:length(annealingList)){
    if (annealingList[[i]]$lObs > keepParams$lObs){
      keepParams <- annealingList[[i]]
    }  
  }	
  return(keepParams)
}

