generateData <- function(P, thetas, epsilon, mus, sigma2, N, betas=NULL, isoReg=TRUE){
	ne <- ncol(P)
        P <- transitiveClosure(P)
	H <- hyperCube(ne)
	G <- as.logical(orderIdeals(H, P)$G)
	z <- g <- x <- rep(0,ne)
	modelData <- as.data.frame(matrix(rep(as.numeric(NA), (2*ne+1)*N), nr=N))
	colnames(modelData) <- c("y",  paste("x", 1:ncol(P), sep=""), paste("z", 1:ncol(P), sep=""))
	for (i in 1:N){
		## Draw number of events from Bernoulli, parameter of distribution is given by theta[e]
		for (e in 1:ne){
			z[e] <- as.integer(runif(1)<=thetas[e])
		}
		## Events can only occur if all predecessor have occured. True genotype is g.
		## Checking predecessors is done by scanning the poset.
		for (e in 1:ne){
			pred <- which(P[,e]==1)
			if (length(pred)>0){ # there is a predecessor
				g[e] <- z[e]* prod(z[pred])
			} else { # no predecessor, independent event
				g[e] <- z[e]
			}
		}
		## Add errors by flipping events, probability is Bernoulli, parameter is epsilon. 
		for (e in 1:ne){
			if (runif(1)<=epsilon){
				x[e] <- as.integer(!g[e])
			} else {
				x[e] <- g[e]
			}
		}
		## Find out index of order ideal the true genotype belongs to
		E <- ne - (1:ne) # index of g  =  1 + sum(pow2(g, E))
		idxHypercube <- 1 + sum(g*2^E)
		## Index of the parameter in mus
		idxParameter <- sum(G[1:idxHypercube])
		## Use parameters mu[idx] and sigma2 to draw y
		mu <- mus[idxParameter]
		if (isoReg){ # isotonic regression, y_i = N(mu_g, sigma2)
		  y <- rnorm(1, mean=mu, sd=sqrt(sigma2))
    } else { # linear regression, y_i = N(g_i * betas, sigma2)-> based on the true genotype!!
      y <- rnorm(1, mean=c(1,g)%*%betas, sd=sqrt(sigma2))
    }
		modelData[i,] <- c(y, x, g)
	}
	return(modelData)
}

