tryEdge <- function(X, Y, params, T, tAlpha=0.05, logLikNext, weightsNext, parsNext, eps=1, maxIter=100, logging=TRUE){
	P <- params$P
	logLik <- params$lObs
	p <- ncol(P)
	alpha <- checkCompatibility(X, P)
	if (is.null(weightsNext)){
		if (logging) { cat("Need to calculate weight matrix.\n") }
		alphaAll <- weightMoves(X, P)
		weightsNext <- alphaAll
		if (logging) {cat("Calculating weight matrix done.\n") }
	} else {
		if (logging) { cat("Reusing weight matrix.\n") }
		alphaAll <- weightsNext
	}
	randVec <- sample(1:p^2,p^2)
	if (logging) { cat("Preselecting poset using Boltzmann.\n") }
	for (i in 1:p^2){
		rr <- floor((randVec[i]-1) / p) + 1
		cc <- (randVec[i]-1) %% p + 1
		if (logging) { cat("Try", i, "from", p^2, "row:", rr, "column:", cc, ".\n") }
		if (logging) { cat("Relation", colnames(X)[rr], "->", colnames(X)[cc], ".\n") }
		if (rr == cc) {
			if (logging) { cat("No relations on diagonal are allowed!\n")}
			next
		}
 		if (alphaAll[rr,cc] < alpha){
			random <- runif(1)
			boltz <- exp((alphaAll[rr,cc] - alpha ) / tAlpha )
 			if (logging) {
 				cat("Alpha proposed smaller, Boltzmann choice, random:", random, ", Boltzmann:", boltz, "\n")
 				cat("Alpha proposed:", alphaAll[rr,cc], ", alpha old:", alpha, ", tAlpha used:", tAlpha, "\n")
 			}
			if (random < boltz){
				if (logging) { cat("Alpha accepted by Boltzmann choice.\n")	}
			} else {
				if (logging) { cat("Alpha rejected by Boltzmann choice, abandoning edge change.\n")}
				next
			}
		} else {
		 if (logging) { cat("Alpha proposed higher, proposal accepted.\n")}
		}
		M <- P
		M[rr,cc] <- !P[rr,cc] # flip relation
		if (M[rr,cc]){ # cheange was ADD
			if (logging) { cat("Change done is ADD.\n")}
			M <- hasse(M)
			if (isAcyclic(M)){ # No loop in new poset
				if (logging) { cat("New poset is acyclic\n")}
				if (!M[rr,cc]){  # relation was removed
					if (logging) { cat("Relation was removed, no cover relation.\n")}
					count <- 0
					for(i in 1:p){
						if(M[rr,i] & M[i,cc]){ # Check if single intermediate state, ie R1 -> j -> R2
							j <-  i
							count <- count+1
						}
					}
					if(count == 1){
						if (logging) { cat("Only one intermediate, reassembling.\n")}
						M[j,cc] <- 0 # Remove j -> R2
						M[rr,cc] <- 1 # Add R1 -> R2
					} else { # More than one intermediate state
						if (logging) { cat("More than one intermediate, abandoning edge seletion.\n")}
						next	 # proposal is no good
					}
					M1 <- hasse(M)
					if (any(M1 != M) | (!isAcyclic(M1))){  # if removed or cyclic
						if (logging) { cat("Proposal either cyclic or not a cover relation, abandoning edge selection.\n")}
						next # no good
					}
				}
			} else {
				if (logging) { cat("Cyclic desaster, abandoning edge selection.\n")}
				next
			}
		} else { # Change was DELETE
			if (logging) { cat("Change was DELETE.\n")}
 			M <- hasse(M)
		}
		if (logging) { 
			cat("Done preselecting new poset\n")
			cat("Old poset: ", unlist(P), "\n")
			cat("New poset: ", unlist(M), "\n")
		}
		
##################
		if (logLikNext[rr,cc] == 0){ # Check if loglik has been computed before
			if (logging) { cat("Need to calculate llh. Resetting parameters!\n")}
			newPars <- guessParams(X, Y, M)
			if (logging) { printParams(newPars, message="Initalized parameters")}
			newPars <- doEm(X, Y, newPars, eps=eps, maxIter=maxIter)
	  	logLikNext[rr,cc] <-  newPars$lObs
	  	parsNext[[paste("R", rr, "C", cc,sep="")]] <- newPars
	  	if (logging) { cat("Calculating llh done.\n")}
	  } else {
	  	if (logging) { cat("Reusing precalculated llh.\n")}
	  }
	  logLikNew <- logLikNext[rr,cc]
	  newPars <- parsNext[[paste("R", rr, "C", cc,sep="")]]
		if (logging) { printParams(newPars, message="Actual parameters")}
		if (logLikNew > logLik){ # Always accept increasing Loglik
			if (logging) { cat("llh proposed higher, proposal accepted.\n")}
			logLikNext <- matrix(0, nc=p, nr=p) # Re-initialize possible logliks
			parsNext <- list()
			return(list(params=newPars, logLikNext=logLikNext, weightsNext=NULL, parsNext=parsNext))
		} else { # Accept decreasing Loglik with Boltzmann weight
			random <- runif(1)
			boltz <- exp((logLikNew - logLik ) / T )
			if (logging) { 
				cat("llh proposed smaller, Boltzmann choice, random:", random, ", Boltzmann:", boltz, ".\n")
				cat("llh proposed:" ,logLikNew, ", llh old:", logLik, ".\n")
			}
			if (random < boltz){
				if (logging) { cat("llh accepted by Boltzmann choice.\n")}
				logLikNext <- matrix(0, nc=p, nr=p) # Re-initialize possible logliks
				parsNext <- list()
		  	return(list(params=newPars, logLikNext=logLikNext, weightsNext=NULL, parsNext=parsNext))
			} else {
				if (logging) { cat("llh rejected by Boltzmann choice, abandoning edge change.\n")}
				next
	    }
		}
	}
	if (logging) { cat("No changes accepted in loop, returning initial values.\n")}
	return(list(params=params, logLikNext=logLikNext, weightsNext=weightsNext, parsNext=parsNext))
}
