\name{cvIcbn}
\alias{cvIcbn}
\title{
Does cross-validation of noisy, isotonic, conjunctive bayesian network models.
}
\description{
Returns MSE and COR of ICBN and linar model.
}
\usage{
cvIcbn(fitCbn, X, Y, K, P, epsStop=0.1, maxIter=100)
}
\arguments{
  \item{fitCbn}{
Function doing the actual fitting, usually fitCbn.
}
  \item{X}{
The observed genotypes as binary matrix.
}
  \item{Y}{
The observed phenotype as numerical vector.
}
  \item{K}{
The number of cross-validation partitions.
}
  \item{P}{
The poset under consideration.
}
  \item{epsStop}{
The EM loop stops if the change of likelihood is below this value.
}
  \item{maxIter}{
Determines the maximum number of iterations in the isotonic regression.
}
}
\details{
Returns estimates of the MSE, COR and the respective standard errors 
for linear and CBN model.
}
\value{
  \item{mseLr }{MSE of linear model.}
  \item{mseIcbn }{MSE of ICBN model.}
  \item{corLr}{Correlation linear model.}
  \item{corIcbn }{Correlation ICBN model.}
  \item{seMseLr }{Standard error of MSE linear model.}
  \item{seMseIcbn }{Standard error of MSE ICBN model.}
  \item{seCorLr }{Standard error of COR linear model.}
  \item{seCorIcbn }{Standard error of COR ICBN model.}
  \item{etc}{Raw values of mse and cor for testing. }
}
\author{
Patrick Knupfer
}
\seealso{
  \code{\link{fitCbn}}
}
\examples{
	P <- testPoset
	X <- testData[,-1]
	Y <- testData[,1]
	K <- 3 
	set.seed(42)
	cvIcbn(fitCbn, X, Y, K, P, epsStop=1, maxIter=50)
}
\keyword{ utilities }
