\name{doAnneal}
\alias{doAnneal}
\title{
CBN structure search with simmulated annealing.
}
\description{
The structure searching part encapsulated in a function.
}
\usage{
doAnneal(X, Y, outputPath, tInit = 50, tAlpha = 0.03, tFactor = 1, nIter = 10, epsGuess = 0.03, epsStop = 0.1, 
         maxIter = 100, plotFlag = FALSE, saveFlag = FALSE, loggingFlag = FALSE)
}
\arguments{
  \item{X}{
The observed genotype as a binary matrix.
}
  \item{Y}{
The observed phenotype as numeric vector.
}
  \item{outputPath}{
Output path were the plots and intermediate results are saved.
}
  \item{tInit}{
Inital temperature in the annealing run.
}
  \item{tAlpha}{
The cut-off temperature for the shortcut decision.
}
  \item{tFactor}{
Factor which determines the temperature gradient.
}
  \item{nIter}{
Number of iterations in the annealing run.
}
  \item{epsGuess}{
Epsilon for the inital guess of the poset.
}
  \item{epsStop}{
Epsilon for the EM-step, loop breaking occurs if log likelihood difference below this value.
}
  \item{maxIter}{
Maximum number of iterations in the isotonic regression.
}
  \item{plotFlag}{
Save plots to disk?
}
  \item{saveFlag}{
Save intermediate result to disk?
}
  \item{loggingFlag}{
Write diagnostic messages to the console.
}
}
\details{
Returns the parameter set including poset of the configuration in the annealing
run which showed the highest likelihood.
}
\value{
 \item{thetas}{Optimal thetas found.}
 \item{epsilon}{Optimal epsilon found.}
 \item{mus}{Optimal mus found.}
 \item{sigma2}{Optimal sigma2 found.}
 \item{P}{Optimal poset found.}
 \item{G}{Genotype lattice indices in the hypercube.}
 \item{H}{Hypercube.}
 \item{respMat}{Responsibility matrix.}
 \item{distMat}{Distance matrix.}
 \item{lObs}{Observed log likelihood.}
}
\author{
Patrick Knupfer.
}
\examples{
	Y <- testData[,1]
	X <- testData[,-1]
	set.seed(42)
	doAnneal(X, Y, "myPathName", tInit = 100, tAlpha = 0.03, tFactor = 1, nIter = 10, epsGuess = 0.03, epsStop = 1, 
           maxIter = 50, plotFlag = FALSE, saveFlag = FALSE, loggingFlag = FALSE)
}
\keyword{ utilities }

