\name{estimateMu}
\alias{estimateMu}
\title{ Estimates the parameters mu using isotonic regression }
\description{
Uses the package isotone.
}
\usage{
estimateMu(Y, G, H, respMat, maxIter=100, logging=TRUE)
}
\arguments{
  \item{Y}{ Vector with the measured numeric phenotypes. }
  \item{G}{ Genotype lattice indicating membership of g in G. }
  \item{H}{ The hypercube of possible genotypes. }
  \item{respMat}{ The responsibility matrix calculated in the E-step. }
  \item{maxIter}{ Maximum number of iterations in the isotonic regression estimation.}
  \item{logging}{ Flag to turn on messages to the console.}
}
\details{
  The responsibility matrix has dimensions N times n with N being the number of
  observations and n being the number of genotypes in the genotype lattice.
  The values of y are transformed to sum_i(gamma_ig*mu_g)/sum_i(gamma_ig), the
  values of Ng are replaced by ug.
}
\value{
  A numeric vector with the estimated parameters mu.
  Dimension corresponds to the number of genotypes in the lattice.
}
\author{ Patrick Knupfer }
\examples{
	P <- testPoset
  Y <- testData[,1]
  H <- hyperCube(ncol(P))
  G <- orderIdeals(H, P)$G
  estimateMu(Y, G, H, testResponsibilities)
}
\keyword{ utilities }
