\name{estimateSS}
\alias{estimateSS}
\title{
Get the sum of squares error of the estimated phenotypes.
}
\description{
Determines the SS of a linear, constant and noisy iCBN model.
}
\usage{
estimateSS(X, Y, params)
}
\arguments{
  \item{X}{
The observed genotypes.
}
  \item{Y}{
The observed phenotypes.
}
  \item{params}{
The parameters fitted during the EM algorithm or the last output of the simmulated annealing.
}
}
\details{
The iCBN should do similar or better than the linear model, i.e. the SS must be of the same order.
}
\value{
\item{ssConst }{SS of the constant model.}
\item{ssLr }{SS of the linear regression.}
\item{ssIcbn }{SS of the noisy isotonic conjunctive bayesian network.}
\item{lObs }{The observed log likelihood, i.e. log(L(X,Y)).}
\item{y }{Vector of observed phenotypes.}
\item{yhatConst }{Mean value of the observed phenotypes.}
\item{yhatLr }{Vector with predicted phenotypes using linear regression.}
\item{yhatIcbn }{Vector with predicted phenotypes using noisy ICBN.}
}
\author{
Patrick Knupfer
}
\examples{
	P <- testPoset
	Y <- testData[,1]
	X <- testData[,-1]
	params <- guessParams(X, Y, P, thetas=NULL, epsilon=NULL, mus=NULL, sigma2=NULL)
	set.seed(42)
	params <- doEm(X, Y, params, eps = 0.5, maxIter=50, logging=TRUE)
	estimateSS(X, Y, params)
}
\keyword{ utilities }
