\name{fitCbn}
\alias{fitCbn}
\title{
Helper function for cross-validation of CBN.
}
\description{
Returns the MSE of a linear and CBN fit as well as the correlations.
}
\usage{
fitCbn(idx, X, Y, P, epsStop=0.1, maxIter=100)
}
\arguments{
  \item{idx}{
Row indices to use as validation, the rest is used for training.
}
  \item{X}{
The observed genotypes as binary matrix.
}
  \item{Y}{
The observed phenotypes as numerical vector.
}
  \item{P}{
The poset under consideration.
}
	\item{epsStop}{
EM loop stops if difference in likelihood is below this value.
}
  \item{maxIter}{
Determines the maximum number of iterations in the isotonic regression.
}
}
\details{
Splits the data into training and validation.
Initially guesses CBN parameters and fits them in EM alogrithm.
Determines the beta values of a linear regression.
Parameter estimates are done on training portion, predictions on valdiation portion.
Calls the function predictPheno to obtain predictions and
calculate MSE and COR for the CBN and LR model.
}
\value{
  \item{mseLr }{MSE of linear regression.}
  \item{mseIcbn }{MSE of CBN model.}
  \item{corLr}{Correlation of linear model prediction with observed data.}
  \item{corIcbn}{Correlation of CBN model prediction with observed data.}
}
\author{
Patrick Knupfer
}
\seealso{
  \code{\link{predictPheno}}
}
\examples{
	set.seed(42)
	P <- testPoset
	Y <- testData[,1]
	X <- testData[,-1]
	idx <- sample(1:nrow(X), nrow(X)/2)
	fitCbn(idx, X, Y, P, epsStop=0.1, maxIter=100)
}
\keyword{ utilities }
