\name{generateData}
\alias{generateData}
\title{
Data generator for testing.
}
\description{
Generates data through a noisy isotonic CBN model.
There are 3 components: The CBN determining P(Z), 
an error models determining P(X|Z) and
an isotonic or linear regression determining P(Y|Z). 
}
\usage{
generateData(P, thetas, epsilon, mus, sigma2, N, betas=NULL, isoReg=TRUE)
}
\arguments{
  \item{P}{
The poset determining the CBN structure.
}
  \item{thetas}{
A vector containing the parameters of the CBN, one value of theta per event in the model.
}
  \item{epsilon}{
A parameter determining the error probabilites.
}
  \item{mus}{
A vector containing the average phenotype values associated with a genotype in the lattice.
The number of parameters is given by the number of genotypes in the lattice, i.e. sum(G)
}
  \item{sigma2}{
The variance of phenotypes belonging to the same lattice. One value for all genotypes.
}
  \item{N}{
The number of observations to generate.
}
  \item{betas}{
The parameters for the linear regression. Length = Number of events + 1 for the intercept.
}
  \item{isoReg}{
Flag to define which regression model should be used, isotonic or linear. Defaults to isotonic (=TRUE).
}
}
\details{
Bases on the values of thetas, each event E_1..E_n is drawn from Bernoulli(theta_1..theta_n).
Using the poset the event occurence is set to E_i*E(parents(E_i)) to ensure only events are generated
where all parents have occured.
Next a flip event E_err is drawn from Bernoulli(epsilon) and the events are inverted accordingly.
Last for each geneotype a phenotype value is drawn from a normal distribution based on mu value of the corresponding hidden
genotype and the value of sigma2.
In case of linear regression, y is drawn from N([1,g] * betas, sigma2).
}
\value{
A data frame with the first column being the numeric phenotype value.
The next N columns represent the observed occurence of the N events given in the poset.
The next N columns represent the true occurence of the N events given in the poset.
}
\author{
Patrick Knupfer
}
\examples{
## Specifiy poset
	P <- matrix(c(0,1,0,0,
								0,0,0,0,
								0,1,0,1,
								0,0,0,0), nc=4, byrow=TRUE)
	P <- hasse(transitiveClosure(P))
	colnames(P) <- rownames(P) <- paste("e", 1:ncol(P), sep="")
## Make sure it's correct
#	plotPoset(P, vertexLabels=colnames(P))

## Extract the hypercube and order ideals

	H <- hyperCube(ncol(P))
	rownames(H) <- hyperCubeNames(ncol(P))
	G <- orderIdeals(H, hasse(P))$G
	cat("Number of order ideals: ", sum(G))

## Set parameters for data generation

	thetas <- c(0.4, 0.6, 0.7, 0.8)
	mus <- c(0.0,0.1,0.2,0.1,0.2,0.3,0.3,0.4)
	names(mus) <- hyperCubeNames(nrow(P))[as.logical(orderIdeals(hyperCube(nrow(P)), P)$G)]
	epsilon <- 0.2
	sigma2 <- 0.1
	N <- 200

## Generate the data

	cbnData <- generateData(P, thetas, epsilon, mus, sigma2, N)
	str(cbnData)
}
\keyword{ utilities }
