\name{guessMus}
\alias{guessMus}
\title{
Initial guess of the parameters of the isotonic regression.
}
\description{
In order to speed up convergence, the mu values from 
the previous step are reused. As the poset changes, the 
old mus are mapped to the new ones, for non-existing genotypes
the mus are set in order not to violate the isotonicity constraints.
}
\usage{
guessMus(musOld, G, H)
}
\arguments{
  \item{musOld}{
Named numeric vector with the previous parameters according to the OLD poset. 
}
  \item{G}{
The index of genotypes in the lattice with respect to the hypercube according
to the NEW poset.
}
  \item{H}{
The hypercube.
}
}
\details{
For new genotypes in the lattice, the phenotype values up- or downstream are searched
and the corresponding values are taken.
}
\value{
Named numeric vector containing the new parameters. The length is usually different
from the length of the old parameters.
}
\author{
Patrick Knupfer
}
\examples{
	pOld <- testPoset
	(musOld <- generateMus(pOld, -1, 3))
	pNew <- matrix(c(0,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0), nc=4, byrow=TRUE)
	p <- ncol(pNew)
	hNew <- hyperCube(ncol(pNew))
	gNew <- orderIdeals(hNew, pNew)$G
	guessMus(musOld, gNew, hNew)
}
\keyword{ utilities }
