\name{plotIsotonic}
\alias{plotIsotonic}
\title{
Diagnostic plot of the genotype lattice with the fitted values of the isotonic regression.
}
\description{
Plot the genotype lattice, vertex colors are controlled by quantiles of the phenotype values
predicted by isotonic regression.
Vertex labels are given by concatentating the binary representation of the pattern with
the phenotype values.
}
\usage{
plotIsotonic(mus, G, H, eventNames, ug=NULL, layout=NULL, colorDataQuant=FALSE, noMus=FALSE, ...)
}
\arguments{
  \item{mus}{
The values fitted by isotonic regression. Should have a names attribute with the binary representation of the pattern. 
}
  \item{G}{
The index values of the genotype lattice in the hypercube.
}
  \item{H}{
The hypercube.
}
  \item{eventNames}{
Vector of type character containing the event names for use in the plot title.  
}
  \item{ug}{
The count of observations for that genotype in the lattice. Used for annotating the vertices.
}
  \item{layout}{
A string specifying the layout. Possible values are: "kamada", "lgl", "reingold", NULL is interpreted as "circle".  
}
  \item{colorDataQuant}{
If set, the vertex colors are scaled to quantiles based on the data, else they are scaled to the range -1 to 3.  
}
  \item{noMus}{
If set to true, the values of ug and the mu are not printed in the vertices of the graph and only the pattern
is printed in the vertex. 
}
  \item{...}{
Additional paramters passed to plotPoset.
}
}
\value{
A diagnostic plot of the icbn lattice.
}
\author{
Patrick Knupfer
}
\examples{
	P <- testPoset
	mus <- generateMus(P, -1, 3)
	H <- hyperCube(ncol(P))
	G <- orderIdeals(H, P)$G
	#plotIsotonic(mus, G, H, paste("Event", 1:ncol(P), sep=""), layout="reingold")
}
\keyword{ utilities }