\name{probCbn}
\alias{probCbn}
\title{ Calculates the likelihood of a CBN. }
\description{
Returns Prob(Zi=g | thetas) using the formula
Prod_e_in_g {theta_e} * Prod_e_in_Succ(g) { (1-theta_e) }
Referred to as P_cbn
}
\usage{
probCbn(G, H, thetas)
}
\arguments{
  \item{G}{ A vector of 1 and 0 specifying which genotypes of H are in the genotype lattice. }
  \item{H}{ The hypercube as a matrix containing all possible 2^n genotypes. }
  \item{thetas}{ The conditional probability vector. The length corresponds to the number of events in the event poset. }
}
\details{
  Check Sturmfels et. al. or Beerenwinkel et. al. for details on CBN.
}
\value{
  A numeric vector containing P(Zi=g|thetas) for all g in G. 
}
\author{ Patrick Knupfer }
\examples{
	P <- hasse(testPoset)
	H <- hyperCube(ncol(P))
	G <- orderIdeals(H, P)$G	
	thetas <- c(0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7)
	probCbn(G, H, thetas)
}
\keyword{ utilities }
