\name{probErr}
\alias{probErr}
\title{
Fast version to calculate the probabilities of the error term.
P(xi|zi=g,epsilon,p)=choose(p,d)*epsilon^d*(1-epsilon)^(p-d)
with d beeing the hamming distance between xi and zi.
These distances can be calculated only once and are stored in 
distanceMatrix.
}
\description{
Uses a precomputed distance matrix on the whole hypercube to save time.
}
\usage{
probErr(epsilon, distanceMatrix, p)
}
\arguments{
  \item{epsilon}{
The numeric value of epsilon.
}
  \item{distanceMatrix}{
The distance matrix of all observed genotypes against the genotypes in the lattice genotypes.
}
  \item{p}{
The number of events.
}
}
\details{
Instead of computing the hamming distances over and over again, this is
done only once and the results stored in a distance matrix which is then
used as input to this function which evaluates the error function in a 
vectorized way.
}
\value{
The matrix elements P(xi|zi=g, epsilon, p) also referred to as P_err.
Dimension is N x NG where N is the number of observations and
NG the number of genotypes in the lattice.
}
\author{
Patrick Knupfer
}
\seealso{
\code{\link{computeDistanceMatrix}}
}
\examples{
	P <- hasse(testPoset)
	X <- testData[,-1]
	H <- hyperCube(ncol(P))
	G <- orderIdeals(H, P)$G
	D <- computeDistanceMatrix(X, G, H)
	probErr(0.1, D, ncol(P))
}
\keyword{ utilities }
