\name{probIso}
\alias{probIso}
\title{
Calculates the probability P(yi|zi=g, mus, sigma2) where
P(yi|zi=g) is distributed as Normal(mu_g, sigma2)
}
\description{
Calculates the likelihood part of the isotonic regression.
}
\usage{
probIso(Y, mus, sigma2)
}
\arguments{
  \item{Y}{
The observed phenotypes Y.
}
  \item{mus}{
Parameters of the isotonic regression normal distribution.
}
  \item{sigma2}{
Parameter of the isotonic regression normal distribution.  
}
}
\value{
A matrix containing the probabilities P(yi|zi=g, mus, sigma2)
}
\author{
Patrick Knupfer
}
\examples{
	Y <- zdv[,1]
	X <- zdv[,-1]
	P <- matrix(c(0,0,1,0,1,1,0,
								0,0,1,0,0,0,1,
								0,0,0,0,0,0,0,
								0,0,1,0,0,0,1,
								0,0,1,0,0,0,0,
								0,0,1,0,1,0,0,
								0,0,1,0,0,0,0), nc=7, nr=7, byrow=TRUE)
	P <- hasse(P)
	names <- c('41L','67N','69D','70R','210W','215Y','219Q')
#  plotPoset(P, vertexLabels=names, hasse=TRUE)		
	H <- hyperCube(ncol(P))
	G <- orderIdeals(H, P)$G	
	mus <- 1:sum(G)
	names(mus) <- hyperCubeNames(ncol(P))[as.logical(G)]
	sigma2 <- 0.2
	prob <- probIso(Y, mus, sigma2)
	str(prob)
}
\keyword{ utilities }
