\name{tryEdge}
\alias{tryEdge}
\title{
Tries modifying an edge.
}
\description{
Either adds or deletes an edge.
}
\usage{
tryEdge(X, Y, params, T, tAlpha=0.05, logLikNext, weightsNext, parsNext, eps=1, maxIter=100, logging=TRUE)
}
\arguments{
  \item{X}{
The observed genotype X.
}
  \item{Y}{
The observed phenotype Y.
}
  \item{params}{
The initial parameter, containing theta, epsilon, mu, sigma2, P, G and H.
}
  \item{T}{
The temperature used for the annealing process.
}
  \item{tAlpha}{
The temperature used for the preselection based on compatibilities.
}
  \item{logLikNext}{
Matrix with precalculated log likelihoods.
}
  \item{weightsNext}{
Matrix of the fractions of explained genotypes.
}
  \item{parsNext}{
List of precalculated parameters.
}
  \item{eps}{Maximal log likelihood difference at last step.}
  \item{maxIter}{Maximum number of iterations in the isotonic regression.}
  \item{logging}{Flag to turn on messages to the console.}
}
\details{
Tries adding or deleting an edge.
}
\value{
A list with the following components:
  \item{params }{A list containing the new/old parameters, depending on the acceptance/rejection of the proposal.}
  \item{logLikNext}{Matrix with the precalculated log likelihoods, is filled with zeros if the last change was accepted and the poset changed.}
  \item{parsNext}{List with precalculated parameter sets, is an empty list if the last change was accepted and the poset changed.}
}
\author{
Patrick Knupfer
}
\examples{
	P <- testPoset
	X <- testData[,-1]
	Y <- testData[,1]
	set.seed(42)
	params <- guessParams(X, Y, P, thetas=NULL, epsilon=NULL, mus=NULL, sigma2=NULL)
	logLikNext <- matrix(0, nc=ncol(P), nr=ncol(P))
	weightsNext <- NULL
	parsNext <- list()
	edgeResult <- tryEdge(X, Y, params, 100, tAlpha=0.05, logLikNext, weightsNext, parsNext, 
												eps=1, maxIter=50, logging=TRUE)
	str(edgeResult)
}
\keyword{ utilities }
